# Platyquest - A module

To install platyquest <code><strong>Pip installl platyquest</strong></code>

<h1>To create questions</h1>
This module <code><strong>platyquests</strong></code> will help you to create quiz and make questions
very fast because people would sometimes make many questions in 50 lines of code but this submodule will take 1 line and 
to install it type this command:
<br>
<code><strong>Pip install platyquest</strong></code>

to import it in your project:

><strong>from platyquest import *</strong>

for making 5 question at a time:

> <strong>createquiz() <-- fill the important requirements</strong>

for making a single question:
> <strong>question() <-- fill the requirements</strong>

you can find it n platypy also as <strong>platypy.createquestionsandanswers.</strong>

you can find the basics in my channel:

<a href = "https://www.youtube.com/channel/UCsP5fIAdguQF0muRke5J3zg">https://www.youtube.com/channel/UCsP5fIAdguQF0muRke5J3zg </a>